@@ -3,73 +3,58 @@
 
 """A test base class for tests based on gold file comparison."""
 
+from __future__ import annotations
+
 import difflib
 import filecmp
 import fnmatch
 import os
 import os.path
 import re
-import sys
 import xml.etree.ElementTree
 
+from typing import Iterable, List, Optional, Tuple
+
 from tests.coveragetest import TESTS_DIR
+from tests.helpers import os_sep
 
 
-def gold_path(path):
+def gold_path(path: str) -> str:
     """Get a path to a gold file for comparison."""
     return os.path.join(TESTS_DIR, "gold", path)
 
 
-def versioned_directory(d):
-    """Find a subdirectory of d specific to the Python version.
-    For example, on Python 3.6.4 rc 1, it returns the first of these
-    directories that exists::
-        d/3.6.4.candidate.1
-        d/3.6.4.candidate
-        d/3.6.4
-        d/3.6
-        d/3
-        d
-    Returns: a string, the path to an existing directory.
-    """
-    ver_parts = list(map(str, sys.version_info))
-    for nparts in range(len(ver_parts), -1, -1):
-        version = ".".join(ver_parts[:nparts])
-        subdir = os.path.join(d, version)
-        if os.path.exists(subdir):
-            return subdir
-    raise Exception(f"Directory missing: {d}")                  # pragma: only failure
-
-
 def compare(
-        expected_dir, actual_dir, file_pattern=None,
-        actual_extra=False, scrubs=None,
-        ):
+    expected_dir: str,
+    actual_dir: str,
+    file_pattern: Optional[str] = None,
+    actual_extra: bool = False,
+    scrubs: Optional[List[Tuple[str, str]]] = None,
+) -> None:
     """Compare files matching `file_pattern` in `expected_dir` and `actual_dir`.
 
-    A version-specific subdirectory of `expected_dir` will be used if
-    it exists.
-
     `actual_extra` true means `actual_dir` can have extra files in it
     without triggering an assertion.
 
     `scrubs` is a list of pairs: regexes to find and replace to scrub the
     files of unimportant differences.
 
-    An assertion will be raised if the directories fail one of their
-    matches.
+    If a comparison fails, a message will be written to stdout, the original
+    unscrubbed output of the test will be written to an "/actual/" directory
+    alongside the "/gold/" directory, and an assertion will be raised.
 
     """
-    expected_dir = versioned_directory(expected_dir)
+    __tracebackhide__ = True    # pytest, please don't show me this function.
+    assert os_sep("/gold/") in expected_dir
 
     dc = filecmp.dircmp(expected_dir, actual_dir)
-    diff_files = fnmatch_list(dc.diff_files, file_pattern)
-    expected_only = fnmatch_list(dc.left_only, file_pattern)
-    actual_only = fnmatch_list(dc.right_only, file_pattern)
+    diff_files = _fnmatch_list(dc.diff_files, file_pattern)
+    expected_only = _fnmatch_list(dc.left_only, file_pattern)
+    actual_only = _fnmatch_list(dc.right_only, file_pattern)
 
-    def save_mismatch(f):                                   # pragma: only failure
+    def save_mismatch(f: str) -> None:
         """Save a mismatched result to tests/actual."""
-        save_path = expected_dir.replace("/gold/", "/actual/")
+        save_path = expected_dir.replace(os_sep("/gold/"), os_sep("/actual/"))
         os.makedirs(save_path, exist_ok=True)
         with open(os.path.join(save_path, f), "w") as savef:
             with open(os.path.join(actual_dir, f)) as readf:
@@ -80,7 +65,6 @@ def compare(
     # ourselves.
     text_diff = []
     for f in diff_files:
-
         expected_file = os.path.join(expected_dir, f)
         with open(expected_file) as fobj:
             expected = fobj.read()
@@ -96,16 +80,16 @@ def compare(
         if scrubs:
             expected = scrub(expected, scrubs)
             actual = scrub(actual, scrubs)
-        if expected != actual:                              # pragma: only failure
+        if expected != actual:
             text_diff.append(f'{expected_file} != {actual_file}')
-            expected = expected.splitlines()
-            actual = actual.splitlines()
-            print(f":::: diff {expected_file!r} and {actual_file!r}")
-            print("\n".join(difflib.Differ().compare(expected, actual)))
-            print(f":::: end diff {expected_file!r} and {actual_file!r}")
+            expected_lines = expected.splitlines()
+            actual_lines = actual.splitlines()
+            print(f":::: diff '{expected_file}' and '{actual_file}'")
+            print("\n".join(difflib.Differ().compare(expected_lines, actual_lines)))
+            print(f":::: end diff '{expected_file}' and '{actual_file}'")
             save_mismatch(f)
 
-    if not actual_extra:                                    # pragma: only failure
+    if not actual_extra:
         for f in actual_only:
             save_mismatch(f)
 
@@ -116,53 +100,61 @@ def compare(
         assert not actual_only, f"Files in {actual_dir} only: {actual_only}"
 
 
-def canonicalize_xml(xtext):
-    """Canonicalize some XML text."""
-    root = xml.etree.ElementTree.fromstring(xtext)
-    for node in root.iter():
-        node.attrib = dict(sorted(node.items()))
-    xtext = xml.etree.ElementTree.tostring(root)
-    return xtext.decode("utf-8")
-
-
-def contains(filename, *strlist):
+def contains(filename: str, *strlist: str) -> None:
     """Check that the file contains all of a list of strings.
 
     An assert will be raised if one of the arguments in `strlist` is
     missing in `filename`.
 
     """
+    __tracebackhide__ = True    # pytest, please don't show me this function.
     with open(filename) as fobj:
         text = fobj.read()
     for s in strlist:
         assert s in text, f"Missing content in {filename}: {s!r}"
 
 
-def contains_any(filename, *strlist):
+def contains_rx(filename: str, *rxlist: str) -> None:
+    """Check that the file has lines that re.search all of the regexes.
+
+    An assert will be raised if one of the regexes in `rxlist` doesn't match
+    any lines in `filename`.
+
+    """
+    __tracebackhide__ = True    # pytest, please don't show me this function.
+    with open(filename) as fobj:
+        lines = fobj.readlines()
+    for rx in rxlist:
+        assert any(re.search(rx, line) for line in lines), (
+            f"Missing regex in {filename}: r{rx!r}"
+        )
+
+
+def contains_any(filename: str, *strlist: str) -> None:
     """Check that the file contains at least one of a list of strings.
 
     An assert will be raised if none of the arguments in `strlist` is in
     `filename`.
 
     """
+    __tracebackhide__ = True    # pytest, please don't show me this function.
     with open(filename) as fobj:
         text = fobj.read()
     for s in strlist:
         if s in text:
             return
 
-    assert False, (                         # pragma: only failure
-        f"Missing content in {filename}: {strlist[0]!r} [1 of {len(strlist)}]"
-    )
+    assert False, f"Missing content in {filename}: {strlist[0]!r} [1 of {len(strlist)}]"
 
 
-def doesnt_contain(filename, *strlist):
+def doesnt_contain(filename: str, *strlist: str) -> None:
     """Check that the file contains none of a list of strings.
 
     An assert will be raised if any of the strings in `strlist` appears in
     `filename`.
 
     """
+    __tracebackhide__ = True    # pytest, please don't show me this function.
     with open(filename) as fobj:
         text = fobj.read()
     for s in strlist:
@@ -171,7 +163,15 @@ def doesnt_contain(filename, *strlist):
 
 # Helpers
 
-def fnmatch_list(files, file_pattern):
+def canonicalize_xml(xtext: str) -> str:
+    """Canonicalize some XML text."""
+    root = xml.etree.ElementTree.fromstring(xtext)
+    for node in root.iter():
+        node.attrib = dict(sorted(node.items()))
+    return xml.etree.ElementTree.tostring(root).decode("utf-8")
+
+
+def _fnmatch_list(files: List[str], file_pattern: Optional[str]) -> List[str]:
     """Filter the list of `files` to only those that match `file_pattern`.
     If `file_pattern` is None, then return the entire list of files.
     Returns a list of the filtered files.
@@ -181,11 +181,11 @@ def fnmatch_list(files, file_pattern):
     return files
 
 
-def scrub(strdata, scrubs):
+def scrub(strdata: str, scrubs: Iterable[Tuple[str, str]]) -> str:
     """Scrub uninteresting data from the payload in `strdata`.
     `scrubs` is a list of (find, replace) pairs of regexes that are used on
     `strdata`.  A string is returned.
     """
-    for rgx_find, rgx_replace in scrubs:
-        strdata = re.sub(rgx_find, rgx_replace, strdata)
+    for rx_find, rx_replace in scrubs:
+        strdata = re.sub(rx_find, rx_replace, strdata)
     return strdata
